@@ -14,24 +14,29 @@ of certain tags they know.
 """
 import argparse
 import sys
+
 import taglib
 
+
 def script():
     """Print tags of given files"""
-    parser = argparse.ArgumentParser(description="Print all textual tags of one or more audio files.")
+    parser = argparse.ArgumentParser(
+        description="Print all textual tags of one or more audio files."
+    )
     parser.add_argument("file", nargs="+", help="file(s) to print tags of")
     args = parser.parse_args()
     for i, filename in enumerate(args.file):
-        print(f'{filename}:')
+        print(f"{filename}:")
         file = taglib.File(filename)
         tags = file.tags
         if len(tags) > 0:
             max_key_len = max(len(key) for key in tags.keys())
             for key, values in tags.items():
                 for value in values:
-                    print(f'  {key.ljust(max_key_len)} = {value}')
+                    print(f"  {key.ljust(max_key_len)} = {value}")
         if i < len(args.file) - 1:
             print()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     script()
